package org.jeecg.modules.api.mapper;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.jeecg.modules.api.model.DeviceBreakdownStatVo;
import org.jeecg.modules.api.model.NameValueVO;
import org.jeecg.modules.api.model.RepairPlanStatVO;
import org.jeecg.modules.api.model.WorkOrderStatVO;

import java.util.List;
import java.util.Map;

public interface ScreenDashboardMapper {

    List<RepairPlanStatVO> repairPlanStat(@Param("month") String month);

    WorkOrderStatVO workOrderStat(@Param("month") String month);

    List<NameValueVO> toolBorrowTop(@Param("month") String month);

    List<NameValueVO> materialConsumeTop(@Param("month") String month);

    Map<String, Integer> breakdownMonthStat(@Param("month") String month);

    List<NameValueVO> staffWorkOrderRank(@Param("month") String month);

    List<DeviceBreakdownStatVo> deviceBreakdownNumberStat();
}
